@@ -78,8 +78,8 @@ static int   handle_host_check( int,void * );
 static int   handle_svc_check( int,void * );
 static int   handle_eventhandler( int,void * );
 static int   handle_notifications( int,void * );
-static int   handle_perfdata(int e, void *);
-static int   handle_export(int e, void *);
+static int   handle_perfdata(int, void *);
+static int   handle_export(int, void *);
 static void  set_target_queue( host *, service * );
 static int   handle_process_events( int, void * );
 static void move_results_to_core(struct nm_event_execution_properties *evprop);
@@ -312,9 +312,9 @@ static void move_results_to_core(struct nm_event_execution_properties *evprop) {
 }
 
 /* add list to gearman result list */
-void mod_gm_add_result_to_list(check_result * newcr) {
+void mod_gm_add_result_to_list(check_result * newcheckresult) {
     pthread_mutex_lock(&mod_gm_result_list_mutex);
-    prepend_object_to_objectlist(&mod_gm_result_list, newcr);
+    prepend_object_to_objectlist(&mod_gm_result_list, newcheckresult);
     pthread_mutex_unlock(&mod_gm_result_list_mutex);
 }
 
@@ -472,6 +472,7 @@ static int handle_eventhandler( int event_type, void *data ) {
                          GM_JOB_PRIO_NORMAL,
                          GM_DEFAULT_JOB_RETRIES,
                          mod_gm_opt->transportmode,
+                         1,
                          mod_gm_opt->log_stats_interval
                         ) == GM_OK) {
         gm_log( GM_LOG_TRACE, "handle_eventhandler() finished successfully\n" );
@@ -674,6 +675,7 @@ static int handle_notifications( int event_type, void *data ) {
                          GM_JOB_PRIO_HIGH,
                          GM_DEFAULT_JOB_RETRIES,
                          mod_gm_opt->transportmode,
+                         1,
                          mod_gm_opt->log_stats_interval
                         ) == GM_OK) {
         gm_log( GM_LOG_TRACE, "handle_notifications() finished successfully\n" );
@@ -792,8 +794,6 @@ static int handle_host_check( int event_type, void *data ) {
 #endif
     int check_options;
     struct timeval core_time;
-    struct tm next_check;
-    char buffer1[GM_BUFFERSIZE];
 
     gettimeofday(&core_time,NULL);
 
@@ -828,7 +828,10 @@ static int handle_host_check( int event_type, void *data ) {
         return NEB_OK;
     }
 
-    gm_log( GM_LOG_DEBUG, "received job for queue %s: %s, check_options: %d\n", target_queue, hostdata->host_name, check_options );
+    if(hostdata->latency < 0)
+        hostdata->latency = 0;
+
+    gm_log(GM_LOG_DEBUG, "received job for queue %s: %s, check_options: %d    latency so far: %.3fs\n", target_queue, hostdata->host_name, check_options, hostdata->latency);
 
     /* as we have to intercept host checks so early
      * (we cannot cancel checks otherwise)
@@ -849,26 +852,17 @@ static int handle_host_check( int event_type, void *data ) {
         return NEBERROR_CALLBACKCANCEL;
     }
 
-    /* log latency */
-    if(mod_gm_opt->debug_level >= GM_LOG_DEBUG) {
-        localtime_r(&hst->next_check, &next_check);
-        strftime(buffer1, sizeof(buffer1), "%Y-%m-%d %H:%M:%S", &next_check );
-        gm_log( GM_LOG_DEBUG, "host: '%s', next_check is at %s, latency so far: %i\n", hst->name, buffer1, ((int)core_time.tv_sec - (int)hst->next_check));
-    }
-
     /* set the execution flag */
     hst->is_executing=TRUE;
 
     gm_log( GM_LOG_TRACE, "cmd_line: %s\n", processed_command );
 
     temp_buffer[0]='\x0';
-    snprintf( temp_buffer,GM_MAX_OUTPUT-1,"type=host\nresult_queue=%s\nhost_name=%s\nstart_time=%ld.0\nnext_check=%ld.0\ntimeout=%d\ncore_time=%Lf\ncommand_line=%s\n\n\n",
+    snprintf( temp_buffer,GM_MAX_OUTPUT-1,"type=host\nresult_queue=%s\nhost_name=%s\ncore_time=%Lf\ntimeout=%d\ncommand_line=%s\n\n\n",
               mod_gm_opt->result_queue,
               hst->name,
-              hst->next_check,
-              hst->next_check,
+              timeval2double(&core_time) - hostdata->latency, // can only assume planned start date since next_check already advanced to next check and last_check still points to previous check
               host_check_timeout,
-              timeval2double(&core_time),
               processed_command
             );
 
@@ -883,6 +877,7 @@ static int handle_host_check( int event_type, void *data ) {
                          GM_JOB_PRIO_NORMAL,
                          GM_DEFAULT_JOB_RETRIES,
                          mod_gm_opt->transportmode,
+                         1,
                          mod_gm_opt->log_stats_interval
                         ) == GM_OK) {
     }
@@ -944,8 +939,6 @@ static int handle_svc_check( int event_type, void *data ) {
 #endif
     int check_options;
     struct timeval core_time;
-    struct tm next_check;
-    char buffer1[GM_BUFFERSIZE];
 
     gettimeofday(&core_time,NULL);
 
@@ -980,7 +973,10 @@ static int handle_svc_check( int event_type, void *data ) {
         return NEB_OK;
     }
 
-    gm_log( GM_LOG_DEBUG, "received job for queue %s: %s - %s, check_options: %d\n", target_queue, svcdata->host_name, svcdata->service_description, check_options );
+    if(svcdata->latency < 0)
+        svcdata->latency = 0;
+
+    gm_log(GM_LOG_DEBUG, "received job for queue %s: %s - %s, check_options: %d   latency so far: %.3fs\n", target_queue, svcdata->host_name, svcdata->service_description, check_options, svcdata->latency);
 
     /* as we have to intercept service checks so early
      * (we cannot cancel checks otherwise)
@@ -1000,26 +996,17 @@ static int handle_svc_check( int event_type, void *data ) {
         return NEBERROR_CALLBACKCANCEL;
     }
 
-    /* log latency */
-    if(mod_gm_opt->debug_level >= GM_LOG_DEBUG) {
-        localtime_r(&svc->next_check, &next_check);
-        strftime(buffer1, sizeof(buffer1), "%Y-%m-%d %H:%M:%S", &next_check );
-        gm_log( GM_LOG_DEBUG, "service: '%s' - '%s', next_check is at %s, latency so far: %i\n", svcdata->host_name, svcdata->service_description, buffer1, ((int)core_time.tv_sec - (int)svc->next_check));
-    }
-
     /* set the execution flag */
     svc->is_executing=TRUE;
 
     gm_log( GM_LOG_TRACE, "cmd_line: %s\n", processed_command );
 
     temp_buffer[0]='\x0';
-    snprintf( temp_buffer,GM_MAX_OUTPUT-1,"type=service\nresult_queue=%s\nhost_name=%s\nservice_description=%s\nstart_time=%ld.0\nnext_check=%ld.0\ncore_time=%Lf\ntimeout=%d\ncommand_line=%s\n\n\n",
+    snprintf( temp_buffer,GM_MAX_OUTPUT-1,"type=service\nresult_queue=%s\nhost_name=%s\nservice_description=%s\ncore_time=%Lf\ntimeout=%d\ncommand_line=%s\n\n\n",
               mod_gm_opt->result_queue,
               svcdata->host_name,
               svcdata->service_description,
-              svc->next_check,
-              svc->next_check,
-              timeval2double(&core_time),
+              timeval2double(&core_time) - svcdata->latency, // can only assume planned start date since next_check already advanced to next check and last_check still points to previous check
               service_check_timeout,
               processed_command
             );
@@ -1039,6 +1026,7 @@ static int handle_svc_check( int event_type, void *data ) {
                          prio,
                          GM_DEFAULT_JOB_RETRIES,
                          mod_gm_opt->transportmode,
+                         1,
                          mod_gm_opt->log_stats_interval
                         ) == GM_OK) {
         gm_log( GM_LOG_TRACE, "handle_svc_check() finished successfully\n" );
@@ -1263,7 +1251,7 @@ static void set_target_queue( host *hst, service *svc ) {
 
     if ( svc ) {
         /* pass into the general service queue */
-        if ( mod_gm_opt->services == GM_ENABLED && svc ) {
+        if ( mod_gm_opt->services == GM_ENABLED ) {
             snprintf( target_queue, GM_SMALLBUFSIZE-1, "service" );
             return;
         }
@@ -1287,7 +1275,6 @@ int handle_perfdata(int event_type, void *data) {
     host *hst        = NULL;
     service *svc     = NULL;
     int has_perfdata = FALSE;
-    int i;
     char *perf_data;
 
     gm_log( GM_LOG_TRACE, "handle_perfdata(%d)\n", event_type );
@@ -1385,6 +1372,7 @@ int handle_perfdata(int event_type, void *data) {
     }
 
     if(has_perfdata == TRUE) {
+        int i = 0;
         for (i = 0; i < mod_gm_opt->perfdata_queues_num; i++) {
             char *perfdata_queue = mod_gm_opt->perfdata_queues_list[i];
             /* add our job onto the queue */
@@ -1396,6 +1384,7 @@ int handle_perfdata(int event_type, void *data) {
                                  GM_JOB_PRIO_NORMAL,
                                  GM_DEFAULT_JOB_RETRIES,
                                  mod_gm_opt->transportmode,
+                                 1,
                                  mod_gm_opt->log_stats_interval
                                 ) == GM_OK) {
                 gm_log( GM_LOG_TRACE, "handle_perfdata() successfully added data to %s\n", perfdata_queue );
@@ -1412,7 +1401,7 @@ int handle_perfdata(int event_type, void *data) {
 
 /* handle generic exports */
 int handle_export(int callback_type, void *data) {
-    int i, debug_level_orig, return_code;
+    int debug_level_orig, return_code;
     char * buffer;
     char * type;
     char * event_type;
@@ -1525,8 +1514,8 @@ int handle_export(int callback_type, void *data) {
     }
 
     if(temp_buffer[0] != '\x0') {
-
-        for(i=0;i<mod_gm_opt->exports[callback_type]->elem_number;i++) {
+        int i = 0;
+        for(i = 0; i<mod_gm_opt->exports[callback_type]->elem_number; i++) {
             return_code = mod_gm_opt->exports[callback_type]->return_code[i];
             add_job_to_queue( &client,
                               mod_gm_opt->server_list,
@@ -1536,6 +1525,7 @@ int handle_export(int callback_type, void *data) {
                               GM_JOB_PRIO_NORMAL,
                               GM_DEFAULT_JOB_RETRIES,
                               mod_gm_opt->transportmode,
+                              1,
                               mod_gm_opt->log_stats_interval
                             );
         }
